@@ -305,19 +305,6 @@ ec_driver_prompt_dialog_new (void)
 	return g_object_new (EC_TYPE_DRIVER_PROMPT_DIALOG, NULL);
 }
 
-/*
-* Some makes in the Foomatic database are in abreviated form
-* and must be translated back to a more readable name
-*/
-static gchar *
-translate_make (gchar *make)
-{
-	if (strcmp (make, "HP") == 0)
-		return g_strdup ("Hewlett-Packard");
-	else
-		return g_strdup (make);
-}
-
 static gint
 default_tree_sort_on_first_col_func (GtkTreeModel *model,
                                      GtkTreeIter *a,
@@ -613,13 +600,12 @@ processChars (void *user_data,
 
 	switch (dlg->priv->parse_state) {
 	case PARSE_STATE_MAKE:
-		g_free (dlg->priv->current_driver.make);
-		dlg->priv->current_driver.make = translate_make (text);
-		g_free (text);
+		if (!dlg->priv->current_driver.make)
+			dlg->priv->current_driver.make = text;
 		break;
 	case PARSE_STATE_MODEL:
-		g_free (dlg->priv->current_driver.model);
-		dlg->priv->current_driver.model = text;
+		if (!dlg->priv->current_driver.model)
+			dlg->priv->current_driver.model = text;
 		break;
 	case PARSE_STATE_DRIVER:
 		g_free (dlg->priv->current_driver.driver);
@@ -882,76 +868,6 @@ gconf_set_printer_driver (gchar *reported_make,
 	g_object_unref (gconf_client);
 }
 
-/* FIXME: This function needs to propagate errors
- */
-gboolean
-dbus_match_printer_driver (const gchar  *make, 
-			   const gchar  *model, 
-			   gchar       **driver)
-{
-	DBusConnection *connection;
-	DBusMessage *message = NULL;
-	DBusMessage *reply = NULL;
-	DBusMessageIter iter;
-	DBusError error;
-        const gchar *value;
-	gboolean driver_matches = FALSE;
-
-        if (driver)
-		*driver = NULL;
-
-	if (make == NULL || model == NULL)
-		return FALSE;
-
-	connection = dbus_bus_get (DBUS_BUS_SYSTEM, NULL);
-	if (connection == NULL) 
-		return TRUE;
-                                                                                
-	message = dbus_message_new_method_call (CUPS_DRIVER_CONFIG_NAMESPACE,
-        	                                CUPS_DRIVER_CONFIG_PATH,
-                                                CUPS_DRIVER_CONFIG_NAMESPACE,
-                	                        CUPS_DRIVER_CONFIG_MATCH_DRIVER_METHOD);
-	if (!message) {
-		driver_matches = TRUE;
-		goto out;
-	}
-                                                                                
-	dbus_message_iter_init_append (message, &iter);
-	dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &make);
-	dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &model);
-
-	dbus_error_init (&error);
-	reply = dbus_connection_send_with_reply_and_block (connection, message, 10000, &error);
-	if (dbus_error_is_set (&error)) {
-	      if (dbus_error_has_name (&error, CUPS_DRIVER_CONFIG_DRIVER_NOT_FOUND_ERROR)) {
-		    driver_matches = FALSE;
-	      } else {
-		    driver_matches = TRUE;
-	      }
-	      goto out;
-	}
-	
-	if (!dbus_message_get_args (reply, &error,
-                                    DBUS_TYPE_STRING, &value,
-                                    DBUS_TYPE_INVALID)) {
-		dbus_error_free (&error);
-		driver_matches = TRUE;
-	} else if (driver) {
-		*driver = g_strdup (value);
-		driver_matches = TRUE;
-	}
-	
- out:
-	dbus_connection_flush (connection);
-	if (message)
-		dbus_message_unref (message);
-	if (reply)
-		dbus_message_unref (reply);
-	dbus_connection_unref (connection);
-	
-	return driver_matches;
-}
-
 gboolean
 dbus_set_printer_driver (const gchar *make,
                          const gchar *model,
@@ -962,22 +878,19 @@ dbus_set_printer_driver (const gchar *make,
 	DBusConnection *connection;
 	DBusMessage *message;
 	DBusMessageIter iter;
-                                                                                
+
 	connection = dbus_bus_get (DBUS_BUS_SYSTEM, error);
 	if (connection == NULL) 
 		return FALSE;
-                                                                                
-	message = dbus_message_new_method_call (CUPS_DRIVER_CONFIG_NAMESPACE,
-        	                                CUPS_DRIVER_CONFIG_PATH,
-                                                CUPS_DRIVER_CONFIG_NAMESPACE,
-                	                        CUPS_DRIVER_CONFIG_SET_DRIVER_METHOD);
-                                                                                
+
+	message = dbus_message_new_method_call (HAL_NAMESPACE,
+        	                                udi,
+                                                HAL_PRINTER_INTERFACE,
+                	                        HAL_PRINTER_CONFIG_METHOD);
+				
 	dbus_message_iter_init_append (message, &iter);
 	dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &make);
 	dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &model);
-	dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &udi);
-	dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &name);
-
 
 	if (!dbus_connection_send (connection, message, NULL))
 		return FALSE;
@@ -1027,8 +940,8 @@ on_ok_button_clicked (GtkButton *button,
                                                                GTK_MESSAGE_ERROR,
                                                                GTK_BUTTONS_CLOSE,
                                                                "%s", error.message);
-
 			gtk_dialog_run (GTK_DIALOG (error_dialog));
+
 			dbus_error_free (&error);
 		}
 
