@@ -25,6 +25,7 @@
 #include "ec-tray-icon.h"
 #include "rb-debug.h"
 #include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomeui/libgnomeui.h>
 
 G_DEFINE_TYPE(ECJobList, ec_job_list, GNOME_TYPE_APP)
@@ -538,7 +539,7 @@ cancel_cb (GtkWidget *widget,
 			queue = gnome_cups_queue_get (job_data->printer);
 			
 			error = NULL;
-			gnome_cups_queue_cancel_job (queue, job_data->job->id, 
+			gnome_cups_queue_cancel_job (queue, job_data->local_jobid, 
 						     &error);
 			
 			if (error) {
@@ -969,9 +970,13 @@ set_cell_size (GtkTreeViewColumn *tree_column,
 			pages = MAX (job->pages, job->pages_complete);
 	
 			if (pages > 0)				
-			    size = g_strdup_printf ("%d pages", pages);
+			    size = g_strdup_printf (ngettext ("%d page", "%d pages", pages), pages);
 			else
-			    size = g_strdup_printf ("%ldk", job->size / 1024);
+			    /* Translators: This is the size of print jobs in kibibytes, and
+			     * expands to "42k" for 42 kibibytes. Do not translate the "job size|" prefix.
+			     * Remove it instead.
+			     */
+			    size = g_strdup_printf (Q_("job size|%ldk"), job->size / 1024);
 		}
 	else
 		size = g_strdup ("?");
